@@ -236,8 +236,9 @@ class AddTorrentDialog(component.Component):
             _('Duplicate torrent(s)'),
             _(
                 'You cannot add the same torrent twice.'
-                ' %d torrents were already added.' % count
-            ),
+                ' %d torrents were already added.'
+            )
+            % count,
             self.dialog,
         ).run()
 
@@ -379,7 +380,7 @@ class AddTorrentDialog(component.Component):
         self.listview_files.expand_row(root, False)
 
     def prepare_file(self, _file, file_name, file_num, download, files_storage):
-        first_slash_index = file_name.find(os.path.sep)
+        first_slash_index = file_name.find('/')
         if first_slash_index == -1:
             files_storage[file_name] = (file_num, _file, download)
         else:
@@ -397,7 +398,7 @@ class AddTorrentDialog(component.Component):
     def add_files(self, parent_iter, split_files):
         ret = 0
         for key, value in split_files.items():
-            if key.endswith(os.path.sep):
+            if key.endswith('/'):
                 chunk_iter = self.files_treestore.append(
                     parent_iter, [True, key, 0, -1, False, 'folder-symbolic']
                 )
@@ -584,10 +585,10 @@ class AddTorrentDialog(component.Component):
                 self.build_priorities(
                     self.files_treestore.iter_children(_iter), priorities
                 )
-            elif not self.files_treestore.get_value(_iter, 1).endswith(os.path.sep):
-                priorities[
-                    self.files_treestore.get_value(_iter, 3)
-                ] = self.files_treestore.get_value(_iter, 0)
+            elif not self.files_treestore.get_value(_iter, 1).endswith('/'):
+                priorities[self.files_treestore.get_value(_iter, 3)] = (
+                    self.files_treestore.get_value(_iter, 0)
+                )
             _iter = self.files_treestore.iter_next(_iter)
         return priorities
 
@@ -985,7 +986,10 @@ class AddTorrentDialog(component.Component):
     def _on_filename_edited(self, renderer, path, new_text):
         index = self.files_treestore[path][3]
 
-        new_text = new_text.strip(os.path.sep).strip()
+        # Ensure agnostic path separator
+        new_text = new_text.replace('\\', '/')
+
+        new_text = new_text.strip('/').strip()
 
         # Return if the text hasn't changed
         if new_text == self.files_treestore[path][1]:
@@ -1012,10 +1016,10 @@ class AddTorrentDialog(component.Component):
                 for row in self.files_treestore[parent].iterchildren():
                     if new_text == row[1]:
                         return
-            if os.path.sep in new_text:
+            if '/' in new_text:
                 # There are folders in this path, so we need to create them
                 # and then move the file iter to top
-                split_text = new_text.split(os.path.sep)
+                split_text = new_text.split('/')
                 for s in split_text[:-1]:
                     parent = self.files_treestore.append(
                         parent, [True, s, 0, -1, False, 'folder-symbolic']
@@ -1068,19 +1072,19 @@ class AddTorrentDialog(component.Component):
             # we can construct the new proper paths
 
             # We need to check if this folder has been split
-            if os.path.sep in new_text:
+            if '/' in new_text:
                 # It's been split, so we need to add new folders and then re-parent
                 # itr.
                 parent = self.files_treestore.iter_parent(itr)
-                split_text = new_text.split(os.path.sep)
+                split_text = new_text.split('/')
                 for s in split_text[:-1]:
                     # We don't iterate over the last item because we'll just use
                     # the existing itr and change the text
                     parent = self.files_treestore.append(
-                        parent, [True, s + os.path.sep, 0, -1, False, 'folder-symbolic']
+                        parent, [True, s + '/', 0, -1, False, 'folder-symbolic']
                     )
 
-                self.files_treestore[itr][1] = split_text[-1] + os.path.sep
+                self.files_treestore[itr][1] = split_text[-1] + '/'
 
                 # Now re-parent itr to parent
                 reparent_iter(self.files_treestore, itr, parent)
@@ -1093,7 +1097,7 @@ class AddTorrentDialog(component.Component):
             else:
                 # This was a simple folder rename without any splits, so just
                 # change the path for itr
-                self.files_treestore[itr][1] = new_text + os.path.sep
+                self.files_treestore[itr][1] = new_text + '/'
 
             # Walk through the tree from 'itr' and add all the new file paths
             # to the 'mapped_files' option
